=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2010-10-02 21:15:42 +0000
+++ drizzled/db.cc	2010-10-07 20:00:40 +0000
@@ -360,23 +360,6 @@
 
   LOCK_open.lock(); /* Part 2 of rm a table */
 
-  /*
-    If we have the table in the definition cache, we don't have to check the
-    .frm cursor to find if the table is a normal table (not view) and what
-    engine to use.
-  */
-
-  for (table= tables; table; table= table->next_local)
-  {
-    TableIdentifier identifier(table->db, table->table_name);
-    TableShare *share;
-    table->setDbType(NULL);
-    if ((share= TableShare::getShare(identifier)))
-    {
-      table->setDbType(share->db_type());
-    }
-  }
-
   if (lock_table_names_exclusively(session, tables))
   {
     LOCK_open.unlock();

=== modified file 'drizzled/message/statement_transform.cc'
--- drizzled/message/statement_transform.cc	2010-10-05 21:14:30 +0000
+++ drizzled/message/statement_transform.cc	2010-10-07 20:26:16 +0000
@@ -127,6 +127,11 @@
 
   switch (source.type())
   {
+  case Statement::ROLLBACK:
+    {
+      sql_strings.push_back("ROLLBACK");
+      break;
+    }
   case Statement::INSERT:
     {
       if (! source.has_insert_header())

=== modified file 'drizzled/message/transaction_reader.cc'
--- drizzled/message/transaction_reader.cc	2010-09-21 19:25:33 +0000
+++ drizzled/message/transaction_reader.cc	2010-10-07 20:26:16 +0000
@@ -174,6 +174,15 @@
     if (should_commit)
       should_commit= isEndStatement(statement);
 
+    /* A ROLLBACK would be the only Statement within the Transaction
+     * since all other Statements will have been deleted from the
+     * Transaction message, so we should fall out of this loop immediately.
+     * We don't want to issue an unnecessary COMMIT, so we change
+     * should_commit to false here.
+     */
+    if (statement.type() == message::Statement::ROLLBACK)
+      should_commit= false;
+
     printStatement(statement);
   }
 

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2010-10-06 18:16:00 +0000
+++ drizzled/sql_table.cc	2010-10-08 03:03:39 +0000
@@ -149,24 +149,6 @@
 
   LOCK_open.lock(); /* Part 2 of rm a table */
 
-  /*
-    If we have the table in the definition cache, we don't have to check the
-    .frm cursor to find if the table is a normal table (not view) and what
-    engine to use.
-  */
-
-  for (table= tables; table; table= table->next_local)
-  {
-    TableIdentifier identifier(table->db, table->table_name);
-    TableShare *share;
-    table->setDbType(NULL);
-
-    if ((share= TableShare::getShare(identifier)))
-    {
-      table->setDbType(share->db_type());
-    }
-  }
-
   if (not drop_temporary && lock_table_names_exclusively(session, tables))
   {
     LOCK_open.unlock();

